==> airbridge_flutter_sdk-1.0.0.tar.gz: ios/Classes/AFLPlacementAPI.m <==
//
//  AFLPlacementAPI.m
//  airbridge_flutter_sdk
//
//  Created by WOF on 15/10/2019.
//

#import "AFLPlacementAPI.h"

#import "AirBridge.h"

// AB
#import "ABGet.h"

@implementation AFLPlacementAPI

//
// flutter plugin setting
//

+ (void) registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
    FlutterMethodChannel* channel
    = [FlutterMethodChannel methodChannelWithName:@"airbridge_flutter_sdk/method/placement"
                                  binaryMessenger:registrar.messenger];
    AFLPlacementAPI* instance = [[AFLPlacementAPI alloc] init];
    
    [registrar addMethodCallDelegate:instance channel:channel];
}

- (void) handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
    NSDictionary* arguments = [ABGet type:NSDictionary.class object:call.arguments];
    
    if ([@"click" isEqualToString:call.method]) {
        [self click:arguments result:result];
    } else if ([@"impression" isEqualToString:call.method]) {
        [self impression:arguments result:result];
    } else {
        result(FlutterMethodNotImplemented);
    }
}

//
// flutter method
//

- (void) click:(nullable NSDictionary*)arguments result:(FlutterResult)result {
    NSString* trackingLink = [ABGet type:NSString.class dictionary:arguments key:@"trackingLink"];
    NSString* deeplink = [ABGet type:NSString.class dictionary:arguments key:@"deeplink"];
    NSString* fallback = [ABGet type:NSString.class dictionary:arguments key:@"fallback"];
    
    [AirBridge.placement click:trackingLink deeplink:deeplink fallback:fallback];
    
    result(nil);
}

- (void) impression:(nullable NSDictionary*)arguments result:(FlutterResult)result {
    NSString* trackingLink = [ABGet type:NSString.class dictionary:arguments key:@"trackingLink"];
    
    [AirBridge.placement impression:trackingLink];
    
    result(nil);
}

@end

==> airbridge_flutter_sdk-1.1.0.tar.gz: ios/Classes/AFLPlacementAPI.m <==
//
//  AFLPlacementAPI.m
//  airbridge_flutter_sdk
//
//  Created by WOF on 15/10/2019.
//

#import "AFLPlacementAPI.h"

#import "AirBridge.h"

// AB
#import "AFLGet.h"

@implementation AFLPlacementAPI

//
// flutter plugin setting
//

+ (void) registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
    FlutterMethodChannel* channel
    = [FlutterMethodChannel methodChannelWithName:@"airbridge_flutter_sdk/method/placement"
                                  binaryMessenger:registrar.messenger];
    AFLPlacementAPI* instance = [[AFLPlacementAPI alloc] init];
    
    [registrar addMethodCallDelegate:instance channel:channel];
}

- (void) handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
    NSDictionary* arguments = [AFLGet type:NSDictionary.class object:call.arguments];
    
    if ([@"click" isEqualToString:call.method]) {
        [self click:arguments result:result];
    } else if ([@"impression" isEqualToString:call.method]) {
        [self impression:arguments result:result];
    } else {
        result(FlutterMethodNotImplemented);
    }
}

//
// flutter method
//

- (void) click:(nullable NSDictionary*)arguments result:(FlutterResult)result {
    NSString* trackingLink = [AFLGet type:NSString.class dictionary:arguments key:@"trackingLink"];
    NSString* deeplink = [AFLGet type:NSString.class dictionary:arguments key:@"deeplink"];
    NSString* fallback = [AFLGet type:NSString.class dictionary:arguments key:@"fallback"];
    
    [AirBridge.placement click:trackingLink deeplink:deeplink fallback:fallback];
    
    result(nil);
}

- (void) impression:(nullable NSDictionary*)arguments result:(FlutterResult)result {
    NSString* trackingLink = [AFLGet type:NSString.class dictionary:arguments key:@"trackingLink"];
    
    [AirBridge.placement impression:trackingLink];
    
    result(nil);
}

@end
